@@ -1,9 +1,11 @@
 """Helpers """
 import errno
+import hashlib
 import json
 import logging
 import os
 import os.path
+import sys
 from hashlib import md5
 
 from filelock import FileLock
@@ -13,6 +15,63 @@ LOG = logging.getLogger(__name__)
 _DID_LOG_UNABLE_TO_CACHE = False
 
 
+def get_pkg_unique_identifier():
+    """
+    Generate an identifier unique to the python version, tldextract version, and python instance
+
+    This will prevent interference between virtualenvs and issues that might arise when installing
+    a new version of tldextract
+    """
+    try:
+        # pylint: disable=import-outside-toplevel
+        from tldextract._version import version
+    except ImportError:
+        version = "dev"
+
+    tldextract_version = "tldextract-" + version
+    python_env_name = os.path.basename(sys.prefix)
+    # just to handle the edge case of two identically named python environments
+    python_binary_path_short_hash = hashlib.md5(sys.prefix.encode("utf-8")).hexdigest()[
+        :6
+    ]
+    python_version = ".".join([str(v) for v in sys.version_info[:-1]])
+    identifier_parts = [
+        python_version,
+        python_env_name,
+        python_binary_path_short_hash,
+        tldextract_version,
+    ]
+    pkg_identifier = "__".join(identifier_parts)
+
+    return pkg_identifier
+
+
+def get_cache_dir():
+    """
+    Get a cache dir that we have permission to write to
+
+    Try to follow the XDG standard, but if that doesn't work fallback to the package directory
+    http://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
+    """
+    cache_dir = os.environ.get("TLDEXTRACT_CACHE", None)
+    if cache_dir is not None:
+        return cache_dir
+
+    xdg_cache_home = os.getenv("XDG_CACHE_HOME", None)
+    if xdg_cache_home is None:
+        user_home = os.getenv("HOME", None)
+        if user_home:
+            xdg_cache_home = os.path.join(user_home, ".cache")
+
+    if xdg_cache_home is not None:
+        return os.path.join(
+            xdg_cache_home, "python-tldextract", get_pkg_unique_identifier()
+        )
+
+    # fallback to trying to use package directory itself
+    return os.path.join(os.path.dirname(__file__), ".suffix_cache/")
+
+
 class DiskCache:
     """Disk _cache that only works for jsonable values"""
 
@@ -33,7 +92,7 @@ class DiskCache:
         if not os.path.isfile(cache_filepath):
             raise KeyError("namespace: " + namespace + " key: " + repr(key))
         try:
-            with open(cache_filepath) as cache_file:
+            with open(cache_filepath) as cache_file:  # pylint: disable=unspecified-encoding
                 return json.load(cache_file)
         except (OSError, ValueError) as exc:
             LOG.error("error reading TLD cache file %s: %s", cache_filepath, exc)
@@ -49,7 +108,7 @@ class DiskCache:
 
         try:
             _make_dir(cache_filepath)
-            with open(cache_filepath, "w") as cache_file:
+            with open(cache_filepath, "w") as cache_file:  # pylint: disable=unspecified-encoding
                 json.dump(value, cache_file)
         except OSError as ioe:
             global _DID_LOG_UNABLE_TO_CACHE  # pylint: disable=global-statement
